# AGPL 3 or any later version
# Modern Dark Article Preview Plugin for BDServer
# Replaces ArticlePreview components with modern structured HTML
PluginData = {
    "author":{
        "title":"Madiator2011",
        "url":"https://shark.madiator.com/@madiator2011",
        "avatar":"https://shark.madiator.com/proxy/avatar.webp?url=https%3A%2F%2Fshark.madiator.com%2Ffiles%2F8076a50d-49db-4632-9d21-2e93ed53c500&avatar=1"
    },
    "title":"Modern Homepage",
    "description":"Make your homepage look less ugly.",
    "license":"AGPL-3.0-or-later"}


import re
import html as html_lib

def onHTML(server, html_content):
    """Modern article preview plugin - replaces article preview HTML structure"""
    
    # Remove all Mastodon views entirely
    if '<!-- Render.Mastoview -->' in html_content:
        mastodon_pattern = r'<!-- Render\.Mastoview -->.*?<!-- /Render\.Mastoview -->'
        html_content = re.sub(mastodon_pattern, '', html_content, flags=re.DOTALL)
    
    # Only process pages that contain ArticlePreview components
    if '<!-- Render.ArticlePreview -->' not in html_content:
        return html_content
    
    # Find and replace each article preview
    pattern = r'<!-- Render\.ArticlePreview -->(.*?)<!-- /Render\.ArticlePreview -->'
    
    def replace_article(match):
        original_html = match.group(1)
        article_data = extract_article_data(original_html)
        return generate_modern_article(article_data)
    
    # Replace all article previews
    html_content = re.sub(pattern, replace_article, html_content, flags=re.DOTALL)
    
    # Add modern CSS if not already present
    if 'modern-article-preview-styles' not in html_content:
        css = generate_modern_css()
        html_content = html_content.replace("<body>", "<body>" + css)
    
    # Replace flexity container with modern grid if it contains our articles
    if 'class="modern-article"' in html_content:
        html_content = html_content.replace('<div class="flexity">', '<div class="modern-articles-grid">')
    
    return html_content


def extract_article_data(article_html):
    """Extract data from original article preview HTML"""
    data = {}
    
    # Extract title and URL
    title_match = re.search(r'<a href="([^"]*)"[^>]*><h1[^>]*>(?:<img[^>]*>)?\s*([^<]*)</h1></a>', article_html)
    if title_match:
        data['url'] = html_lib.unescape(title_match.group(1))
        data['title'] = html_lib.unescape(title_match.group(2).strip())
    
    # Extract icon
    icon_match = re.search(r'<img[^>]*alt="\[icon ([^\]]*)\]"[^>]*src="([^"]*)"', article_html)
    if icon_match:
        data['icon'] = html_lib.unescape(icon_match.group(2))
        data['icon_name'] = html_lib.unescape(icon_match.group(1))
    
    # Extract thumbnail
    thumb_match = re.search(r'<img[^>]*alt="\[thumbnail\]"[^>]*src="([^"]*)"', article_html)
    if thumb_match:
        data['thumbnail'] = html_lib.unescape(thumb_match.group(1))
    
    # Extract author info
    author_match = re.search(r'<img[^>]*alt="\[avatar\]"[^>]*src="([^"]*)"[^>]*>.*?<a href="/account/([^"]*)"[^>]*>([^<]*)</a>', article_html, re.DOTALL)
    if author_match:
        data['author_avatar'] = html_lib.unescape(author_match.group(1))
        data['author_username'] = html_lib.unescape(author_match.group(2))
        data['author_display'] = html_lib.unescape(author_match.group(3))
    
    # Extract stats (views and comments)
    stats_match = re.search(r'👁\s*(\d+)\s*💬\s*(\d+)', article_html)
    if stats_match:
        data['views'] = int(stats_match.group(1))
        data['comments'] = int(stats_match.group(2))
    
    # Extract description - looking for content between stats and hashtags/end
    description = ""
    
    # Main pattern: content after stats (views/comments) and before hashtags or article end
    desc_pattern = r'👁\s*\d+\s*💬\s*\d+\s*</center>\s*<br>(.*?)(?:<center>.*?#|</div>)'
    desc_match = re.search(desc_pattern, article_html, re.DOTALL)
    
    if desc_match:
        description = desc_match.group(1)
        # Clean up the description
        description = re.sub(r'<br[^>]*>', ' ', description)
        description = re.sub(r'<!--.*?-->', '', description, flags=re.DOTALL)
        description = re.sub(r'<[^>]*>', '', description)  # Remove any HTML tags
        description = description.strip()
        
        # Check if it's actually content (not just whitespace or default text)
        if description and description not in [' ', '', 'Nothing to see here', '<br>', '<br><br>']:
            data['description'] = description
    
    # Extract hashtags
    hashtag_matches = re.findall(r'<a href="[^"]*text=%23([^"&]*)[^"]*"[^>]*>', article_html)
    if hashtag_matches:
        data['hashtags'] = [html_lib.unescape(tag) for tag in hashtag_matches]
    
    # Check for unread badge
    data['is_unread'] = '<sup>' in article_html
    
    return data


def generate_modern_article(data):
    """Generate modern article preview HTML"""
    
    # Thumbnail section
    thumbnail_html = ""
    if data.get('thumbnail'):
        thumbnail_html = f'''
        <div class="modern-article-thumbnail">
            <a href="{safe_html(data['url'])}">
                <img src="{safe_html(data['thumbnail'])}" alt="Article thumbnail">
            </a>
        </div>
        '''
    
    # Unread badge
    unread_badge = ""
    if data.get('is_unread'):
        unread_badge = '<div class="modern-article-badge">Unread</div>'
    
    # Title section
    icon_html = ""
    if data.get('icon'):
        icon_html = f'<img src="{safe_html(data["icon"])}" alt="" class="modern-article-icon">'
    
    title_html = f'''
    <div class="modern-article-content">
        <a href="{safe_html(data['url'])}" class="modern-article-title">
            {icon_html}
            {safe_html(data.get('title', 'Untitled'))}
        </a>
    '''
    
    # Author section
    author_html = ""
    if data.get('author_username'):
        author_html = f'''
        <div class="modern-article-author-section">
            <img src="{safe_html(data.get('author_avatar', '/icon/user'))}" alt="" class="modern-article-author-avatar">
            <a href="/account/{safe_html(data['author_username'])}" class="modern-article-author">
                {safe_html(data.get('author_display', data['author_username']))}
            </a>
        </div>
        '''
    
    # Stats section
    stats_html = f'''
    <div class="modern-article-stats">
        <span class="modern-stat">👁 {data.get('views', 0)}</span>
        <span class="modern-stat">💬 {data.get('comments', 0)}</span>
    </div>
    '''
    
    # Description section
    description_html = ""
    if data.get('description'):
        description_html = f'''
        <div class="modern-article-preview">
            {safe_html(data['description'])}
        </div>
        '''
    elif not data.get('hashtags'):  # Add fallback for articles without description or hashtags
        description_html = '''
        <div class="modern-article-preview">
            Nothing to see here
        </div>
        '''
    
    # Hashtags section
    hashtags_html = ""
    if data.get('hashtags'):
        tags = ''.join([
            f'<a href="/search?text=%23{safe_html(tag)}&tags=on" class="modern-tag">#{safe_html(tag)}</a>'
            for tag in data['hashtags'][:5]  # Limit to 5 tags
        ])
        hashtags_html = f'<div class="modern-article-tags">{tags}</div>'
    
    # Combine all sections
    article_html = f'''
    <!-- Render.ArticlePreview -->
    <div class="modern-article">
        {unread_badge}
        {thumbnail_html}
        {title_html}
        {author_html}
        {stats_html}
        {description_html}
        {hashtags_html}
        </div>
    </div>
    <!-- /Render.ArticlePreview -->
    '''
    
    return article_html


def extract_mastodon_data(mastodon_html):
    """Extract data from original Mastodon view HTML"""
    data = {}
    
    # Extract URL
    url_match = re.search(r'<a href="([^"]*)"[^>]*>', mastodon_html)
    if url_match:
        data['url'] = html_lib.unescape(url_match.group(1))
    
    # Extract title and icon
    # For non-reposts: <h1><img alt="[icon mastodon]" src="/icon/mastodon" style="vertical-align: middle"> On Mastodon</h1>
    # For reposts: <i>...repost</i><br><br>
    title_match = re.search(r'<h1[^>]*><img[^>]*alt="\[icon ([^\]]*)\]"[^>]*src="([^"]*)"[^>]*>\s*([^<]*)</h1>', mastodon_html)
    if title_match:
        data['icon_name'] = html_lib.unescape(title_match.group(1))
        data['icon_src'] = html_lib.unescape(title_match.group(2))
        data['title'] = html_lib.unescape(title_match.group(3).strip())
    else:
        # Default for reposts or malformed
        data['title'] = 'On Mastodon'
        data['icon_src'] = '/icon/mastodon'
    
    # Check if it's a repost
    data['is_repost'] = '...repost' in mastodon_html
    
    # Extract the actual post content
    # Look for content after stats (</center>) and before User render or end
    # Split the HTML to isolate the content section
    parts = mastodon_html.split('</center>')
    if len(parts) > 1:
        # Get everything after stats
        after_stats = parts[-1]
        
        # Find where User render starts or where the div ends
        user_start = after_stats.find('<!-- Render.User -->')
        div_end = after_stats.find('</div>')
        
        # Determine the end position
        if user_start != -1:
            end_pos = user_start
        elif div_end != -1:
            end_pos = div_end
        else:
            end_pos = len(after_stats)
        
        # Extract content
        content = after_stats[:end_pos].strip()
        
        # Clean up any leading <br> tags
        content = re.sub(r'^<br\s*/?>\s*', '', content)
        content = re.sub(r'^<br\s*/?>\s*', '', content)  # Do it twice for <br><br>
        
        # Only set if we have actual content
        if content and not content.isspace():
            data['content'] = content
    
    # Extract media (images) - look for thumbnail images
    media_match = re.search(r'<center><a href="([^"]*)"[^>]*><img[^>]*alt="\[thumbnail\]"[^>]*src="([^"]*)"[^>]*></a></center>', mastodon_html)
    if media_match:
        data['media'] = [{'url': html_lib.unescape(media_match.group(1)), 'src': html_lib.unescape(media_match.group(2))}]
    
    # Extract author info from User render
    user_match = re.search(r'<!-- Render\.User -->(.*?)<!-- /Render\.User -->', mastodon_html, re.DOTALL)
    if user_match:
        user_html = user_match.group(1)
        # Extract avatar
        avatar_match = re.search(r'<img[^>]*alt="\[avatar\]"[^>]*src="([^"]*)"', user_html)
        if avatar_match:
            data['author_avatar'] = html_lib.unescape(avatar_match.group(1))
        # Extract username and display name
        name_match = re.search(r'<a href="([^"]*)"[^>]*>([^<]*)</a>', user_html)
        if name_match:
            data['author_url'] = html_lib.unescape(name_match.group(1))
            data['author_display'] = html_lib.unescape(name_match.group(2))
    
    # Extract stats
    stats_match = re.search(r'⭐\s*(\d+)\s*💬\s*(\d+)\s*🔁\s*(\d+)', mastodon_html)
    if stats_match:
        data['likes'] = int(stats_match.group(1))
        data['comments'] = int(stats_match.group(2))
        data['reposts'] = int(stats_match.group(3))
    
    # Extract nested repost if present
    nested_match = re.search(r'<!-- Render\.Mastoview -->(.*?)<!-- /Render\.Mastoview -->', mastodon_html[200:], re.DOTALL)
    if nested_match and data.get('is_repost'):
        data['nested_post'] = extract_mastodon_data(nested_match.group(1))
    
    return data


def generate_modern_mastodon(data):
    """Generate modern Mastodon view HTML"""
    
    # Title section with icon
    title = data.get('title', 'On Mastodon')
    icon_src = data.get('icon_src', '/icon/mastodon')
    
    if data.get('is_repost'):
        # For reposts, use italic text instead of header
        title_html = f'''
        <div class="modern-mastodon-header">
            <a href="{safe_html(data.get('url', '#'))}" class="modern-mastodon-repost">
                <i>...repost</i>
            </a>
        </div>
        '''
    else:
        title_html = f'''
        <div class="modern-mastodon-header">
            <a href="{safe_html(data.get('url', '#'))}" class="modern-mastodon-title">
                <img src="{safe_html(icon_src)}" alt="" class="modern-mastodon-icon">
                {safe_html(title)}
            </a>
        </div>
        '''
    
    # Content section
    content_html = ""
    if data.get('content'):
        # The content is already HTML, so don't escape it
        content = data['content']
        content_html = f'''
        <div class="modern-mastodon-content">
            {content}
        </div>
        '''
    
    # Media section
    media_html = ""
    if data.get('media'):
        media_items = ''.join([
            f'''<a href="{safe_html(m['url'])}" target="_blank" class="modern-mastodon-media-link">
                <img src="{safe_html(m['src'])}" alt="Media" class="modern-mastodon-media">
            </a>'''
            for m in data['media']
        ])
        media_html = f'<div class="modern-mastodon-media-grid">{media_items}</div>'
    
    # Author section
    author_html = ""
    if data.get('author_display'):
        author_html = f'''
        <div class="modern-mastodon-author-section">
            <img src="{safe_html(data.get('author_avatar', '/icons/user.png'))}" alt="" class="modern-mastodon-author-avatar">
            <a href="{safe_html(data.get('author_url', '#'))}" class="modern-mastodon-author">
                {safe_html(data['author_display'])}
            </a>
        </div>
        '''
    
    # Stats section
    stats_html = f'''
    <div class="modern-mastodon-stats">
        <span class="modern-stat">⭐ {data.get('likes', 0)}</span>
        <span class="modern-stat">💬 {data.get('comments', 0)}</span>
        <span class="modern-stat">🔁 {data.get('reposts', 0)}</span>
    </div>
    '''
    
    # Nested repost section
    nested_html = ""
    if data.get('nested_post'):
        nested = data['nested_post']
        # Nested content is also HTML
        nested_content = nested.get('content', '')
        
        # Nested media
        nested_media = ""
        if nested.get('media'):
            nested_media_items = ''.join([
                f'''<a href="{safe_html(m['url'])}" target="_blank" class="modern-mastodon-media-link">
                    <img src="{safe_html(m['src'])}" alt="Media" class="modern-mastodon-nested-media">
                </a>'''
                for m in nested['media']
            ])
            nested_media = f'<div class="modern-mastodon-nested-media-grid">{nested_media_items}</div>'
        
        nested_html = f'''
        <div class="modern-mastodon-nested">
            <div class="modern-mastodon-nested-header">
                <img src="{safe_html(nested.get('author_avatar', '/icons/user.png'))}" alt="" class="modern-mastodon-nested-avatar">
                <a href="{safe_html(nested.get('author_url', '#'))}" class="modern-mastodon-nested-author">
                    {safe_html(nested.get('author_display', 'Unknown'))}
                </a>
            </div>
            <div class="modern-mastodon-nested-content">
                {nested_content}
            </div>
            {nested_media}
            <div class="modern-mastodon-nested-stats">
                <span class="modern-stat">⭐ {nested.get('likes', 0)}</span>
                <span class="modern-stat">💬 {nested.get('comments', 0)}</span>
                <span class="modern-stat">🔁 {nested.get('reposts', 0)}</span>
            </div>
        </div>
        '''
    
    # Combine all sections
    mastodon_html = f'''
    <!-- Render.Mastoview -->
    <div class="modern-mastodon">
        <div class="modern-mastodon-inner">
            {title_html}
            {content_html}
            {media_html}
            {nested_html}
            {author_html}
            {stats_html}
        </div>
    </div>
    <!-- /Render.Mastoview -->
    '''
    
    return mastodon_html


def generate_modern_css():
    """Generate CSS for modern article previews - matches the desired layout"""
    return '''
    <style id="modern-article-preview-styles">
    /* Modern Articles Grid Container */
    .modern-articles-grid {
        display: grid !important;
        grid-template-columns: repeat(auto-fill, minmax(450px, 1fr)) !important;
        gap: 24px !important;
        margin: 0 auto !important;
        padding: 20px !important;
        max-width: 1400px !important;
    }

    /* Modern Article Card */
    .modern-article {
        background: rgba(34, 34, 59, 0.4) !important;
        backdrop-filter: blur(20px) !important;
        border: 1px solid rgba(91, 46, 255, 0.2) !important;
        border-radius: 12px !important;
        overflow: hidden !important;
        transition: all 0.3s !important;
        display: flex !important;
        flex-direction: column !important;
        position: relative !important;
        font-family: system-ui, -apple-system, sans-serif !important;
        color: #F9F9FB !important;
        margin: 0 !important;
    }

    .modern-article:hover {
        transform: translateY(-4px) !important;
        box-shadow: 0 20px 40px rgba(234, 127, 63, 0.15) !important;
        border-color: rgba(234, 127, 63, 0.6) !important;
        background: rgba(34, 34, 59, 0.6) !important;
    }

    .modern-article-badge {
        position: absolute !important;
        top: 16px !important;
        right: 16px !important;
        background: linear-gradient(135deg, #EA7F3F 0%, #E76F51 100%) !important;
        color: #ffffff !important;
        padding: 4px 12px !important;
        border-radius: 16px !important;
        font-size: 12px !important;
        font-weight: 600 !important;
        z-index: 10 !important;
        box-shadow: 0 2px 8px rgba(234, 127, 63, 0.4) !important;
    }

    /* Thumbnail - Full width, no border radius at top */
    .modern-article-thumbnail {
        width: 100% !important;
        height: 220px !important;
        background: linear-gradient(135deg, #22223B 0%, #2E2A8A 100%) !important;
        display: block !important;
        position: relative !important;
        overflow: hidden !important;
        margin: 0 !important;
        padding: 0 !important;
    }

    .modern-article-thumbnail a {
        display: block !important;
        width: 100% !important;
        height: 100% !important;
        margin: 0 !important;
        padding: 0 !important;
    }

    .modern-article-thumbnail img {
        width: 100% !important;
        height: 100% !important;
        object-fit: cover !important;
        display: block !important;
        border-radius: 0 !important;
        margin: 0 !important;
        padding: 0 !important;
        max-width: 100% !important;
        min-width: 100% !important;
    }

    /* Content section with proper padding */
    .modern-article-content {
        padding: 24px !important;
        flex: 1 !important;
        display: flex !important;
        flex-direction: column !important;
    }

    /* Title with icon */
    .modern-article-title {
        font-size: 20px !important;
        font-weight: 600 !important;
        color: #e2e8f0 !important;
        margin: 0 0 16px 0 !important;
        line-height: 1.4 !important;
        text-decoration: none !important;
        display: flex !important;
        align-items: center !important;
        gap: 8px !important;
    }

    .modern-article-title:hover {
        color: #EA7F3F !important;
        text-shadow: 0 0 8px rgba(234, 127, 63, 0.5) !important;
    }

    .modern-article-icon {
        width: 20px !important;
        height: 20px !important;
        filter: brightness(0) invert(1) opacity(0.9) !important;
        flex-shrink: 0 !important;
    }

    /* Author section */
    .modern-article-author-section {
        display: flex !important;
        align-items: center !important;
        gap: 12px !important;
        margin-bottom: 12px !important;
    }

    .modern-article-author-avatar {
        width: 40px !important;
        height: 40px !important;
        border-radius: 50% !important;
        object-fit: cover !important;
        border: 2px solid rgba(61, 246, 196, 0.3) !important;
    }

    .modern-article-author {
        color: #cbd5e1 !important;
        text-decoration: none !important;
        font-size: 14px !important;
        font-weight: 500 !important;
    }

    .modern-article-author:hover {
        color: #EA7F3F !important;
    }

    /* Stats */
    .modern-article-stats {
        display: flex !important;
        gap: 16px !important;
        margin-bottom: 16px !important;
        font-size: 14px !important;
        color: #94a3b8 !important;
    }

    .modern-stat {
        display: flex !important;
        align-items: center !important;
        gap: 4px !important;
    }

    /* Preview text */
    .modern-article-preview {
        color: #cbd5e1 !important;
        line-height: 1.6 !important;
        font-size: 15px !important;
        flex: 1 !important;
        margin: 0 0 16px 0 !important;
    }

    /* Tags */
    .modern-article-tags {
        display: flex !important;
        flex-wrap: wrap !important;
        gap: 8px !important;
        margin-top: auto !important;
    }

    .modern-tag {
        background: rgba(91, 46, 255, 0.1) !important;
        color: #5B2EFF !important;
        padding: 4px 12px !important;
        border-radius: 16px !important;
        font-size: 12px !important;
        text-decoration: none !important;
        transition: all 0.2s !important;
        border: 1px solid rgba(91, 46, 255, 0.2) !important;
    }

    .modern-tag:hover {
        background: rgba(234, 127, 63, 0.2) !important;
        color: #EA7F3F !important;
        transform: translateY(-1px) !important;
        box-shadow: 0 2px 8px rgba(234, 127, 63, 0.2) !important;
    }

    /* Responsive design */
    @media (max-width: 1200px) {
        .modern-articles-grid {
            grid-template-columns: repeat(auto-fill, minmax(400px, 1fr)) !important;
        }
    }

    @media (max-width: 768px) {
        .modern-articles-grid {
            grid-template-columns: 1fr !important;
            padding: 16px !important;
            gap: 16px !important;
        }
        
        .modern-article-thumbnail {
            height: 200px !important;
        }
    }

    /* Modern Mastodon Styles */
    .modern-mastodon {
        background: rgba(34, 34, 59, 0.4) !important;
        backdrop-filter: blur(20px) !important;
        border: 1px solid rgba(91, 46, 255, 0.2) !important;
        border-radius: 12px !important;
        overflow: hidden !important;
        transition: all 0.3s !important;
        font-family: system-ui, -apple-system, sans-serif !important;
        color: #F9F9FB !important;
        margin: 0 !important;
    }

    .modern-mastodon:hover {
        transform: translateY(-4px) !important;
        box-shadow: 0 20px 40px rgba(234, 127, 63, 0.15) !important;
        border-color: rgba(234, 127, 63, 0.6) !important;
        background: rgba(34, 34, 59, 0.6) !important;
    }

    .modern-mastodon-inner {
        padding: 24px !important;
    }

    /* Mastodon Header */
    .modern-mastodon-header {
        margin-bottom: 16px !important;
    }

    .modern-mastodon-title {
        font-size: 18px !important;
        font-weight: 600 !important;
        color: #e2e8f0 !important;
        text-decoration: none !important;
        display: flex !important;
        align-items: center !important;
        gap: 8px !important;
    }

    .modern-mastodon-title:hover {
        color: #EA7F3F !important;
        text-shadow: 0 0 8px rgba(234, 127, 63, 0.5) !important;
    }

    .modern-mastodon-icon {
        width: 20px !important;
        height: 20px !important;
        flex-shrink: 0 !important;
    }

    /* Mastodon Content */
    .modern-mastodon-content {
        color: #cbd5e1 !important;
        line-height: 1.6 !important;
        font-size: 15px !important;
        margin-bottom: 16px !important;
        word-wrap: break-word !important;
    }

    .modern-mastodon-content p {
        margin: 0 0 12px 0 !important;
        color: #cbd5e1 !important;
    }

    .modern-mastodon-content a {
        color: #5B2EFF !important;
        text-decoration: none !important;
        word-break: break-all !important;
    }

    .modern-mastodon-content a:hover {
        color: #EA7F3F !important;
        text-decoration: underline !important;
    }

    .modern-mastodon-content .hashtag {
        background: rgba(91, 46, 255, 0.1) !important;
        color: #5B2EFF !important;
        padding: 2px 8px !important;
        border-radius: 12px !important;
        font-size: 14px !important;
        margin: 0 2px !important;
        display: inline-block !important;
        border: 1px solid rgba(91, 46, 255, 0.2) !important;
    }

    .modern-mastodon-content .hashtag:hover {
        background: rgba(234, 127, 63, 0.2) !important;
        color: #EA7F3F !important;
        border-color: rgba(234, 127, 63, 0.3) !important;
    }

    /* Mastodon Media Grid */
    .modern-mastodon-media-grid {
        display: grid !important;
        grid-template-columns: repeat(auto-fit, minmax(150px, 1fr)) !important;
        gap: 8px !important;
        margin-bottom: 16px !important;
    }

    .modern-mastodon-media-link {
        display: block !important;
        border-radius: 8px !important;
        overflow: hidden !important;
        background: rgba(0, 0, 0, 0.1) !important;
    }

    .modern-mastodon-media {
        width: 100% !important;
        height: auto !important;
        max-height: 200px !important;
        object-fit: cover !important;
        display: block !important;
        transition: transform 0.2s !important;
    }

    .modern-mastodon-media:hover {
        transform: scale(1.05) !important;
    }

    /* Nested Repost */
    .modern-mastodon-nested {
        background: rgba(91, 46, 255, 0.05) !important;
        border: 1px solid rgba(91, 46, 255, 0.2) !important;
        border-radius: 8px !important;
        padding: 16px !important;
        margin-bottom: 16px !important;
    }

    .modern-mastodon-nested-header {
        display: flex !important;
        align-items: center !important;
        gap: 12px !important;
        margin-bottom: 12px !important;
    }

    .modern-mastodon-nested-avatar {
        width: 32px !important;
        height: 32px !important;
        border-radius: 50% !important;
        object-fit: cover !important;
        border: 2px solid rgba(61, 246, 196, 0.3) !important;
    }

    .modern-mastodon-nested-author {
        color: #cbd5e1 !important;
        text-decoration: none !important;
        font-size: 14px !important;
        font-weight: 500 !important;
    }

    .modern-mastodon-nested-author:hover {
        color: #EA7F3F !important;
    }

    .modern-mastodon-nested-content {
        color: #cbd5e1 !important;
        font-size: 14px !important;
        line-height: 1.5 !important;
        margin-bottom: 12px !important;
    }

    .modern-mastodon-nested-media-grid {
        display: grid !important;
        grid-template-columns: repeat(auto-fit, minmax(100px, 1fr)) !important;
        gap: 6px !important;
        margin-bottom: 12px !important;
    }

    .modern-mastodon-nested-media {
        width: 100% !important;
        height: auto !important;
        max-height: 120px !important;
        object-fit: cover !important;
        display: block !important;
        border-radius: 6px !important;
    }

    .modern-mastodon-nested-stats {
        display: flex !important;
        gap: 12px !important;
        font-size: 13px !important;
        color: #94a3b8 !important;
    }

    /* Author Section */
    .modern-mastodon-author-section {
        display: flex !important;
        align-items: center !important;
        gap: 12px !important;
        margin-bottom: 12px !important;
    }

    .modern-mastodon-author-avatar {
        width: 40px !important;
        height: 40px !important;
        border-radius: 50% !important;
        object-fit: cover !important;
        border: 2px solid rgba(61, 246, 196, 0.3) !important;
    }

    .modern-mastodon-author {
        color: #cbd5e1 !important;
        text-decoration: none !important;
        font-size: 14px !important;
        font-weight: 500 !important;
    }

    .modern-mastodon-author:hover {
        color: #EA7F3F !important;
    }

    /* Stats Section */
    .modern-mastodon-stats {
        display: flex !important;
        gap: 16px !important;
        font-size: 14px !important;
        color: #94a3b8 !important;
        margin-top: auto !important;
    }
    
    /* Repost styling */
    .modern-mastodon-repost {
        color: #94a3b8 !important;
        text-decoration: none !important;
        font-size: 14px !important;
        font-style: italic !important;
    }
    
    .modern-mastodon-repost:hover {
        color: #EA7F3F !important;
    }
    </style>
    '''


def safe_html(text):
    """Escape HTML to prevent XSS attacks"""
    if not text:
        return ''
    return html_lib.escape(str(text))
